@@ -332,6 +332,7 @@ base rcParams dictionary."""
         for k, v in six.iteritems(dict(*args, **kwargs)):
             self[k] = v
 
+
 docstrings.delete_params('SubDict.parameters', 'base')
 
 
@@ -362,7 +363,7 @@ class RcParams(dict):
     HEADER = """Configuration parameters of the psyplot module
 
 You can copy this file (or parts of it) to another path and save it as
-PSYPLOTRC. The directory should then be stored in the PSYPLOTCONFIGDIR
+psyplotrc.yml. The directory should then be stored in the PSYPLOTCONFIGDIR
 environment variable."""
 
     msg_depr = "%s is deprecated and replaced with %s; please use the latter."
@@ -768,17 +769,9 @@ environment variable."""
 
         Parameters
         ----------
-        group: str
-            The group of the entry point
         raise_error: bool
             If True, an error is raised when multiple plugins define the same
-            plotter or rcParams key. Otherwise only a warning is raised
-
-        Returns
-        -------
-        dict
-            The plotters configuration dictionaries from the plugins for the
-            :func:`psyplot.project.register_plotter` function"""
+            plotter or rcParams key. Otherwise only a warning is raised"""
 
         pm_env = os.getenv('PSYPLOT_PLOTMETHODS', '').split('::')
         include_pms = [s[4:] for s in pm_env if s.startswith('yes:')]
@@ -1011,7 +1004,7 @@ def validate_dict(d):
         try:
             with open(d) as f:
                 return dict(yaml.load(f))
-        except:
+        except Exception:
             raise ValueError("Could not convert {} to dictionary!".format(d))
 
 
@@ -1108,6 +1101,12 @@ defaultParams = {
         :class:`psyplot.plotter.maps.FieldPlotter` instances, set
         ``{'plotter.fieldplotter.title': 'my title'}``""")],
 
+    'gridweights.use_cdo': [
+        None, validate_bool_maybe_none,
+        'Boolean flag to control whether CDOs (Climate Data Operators) should '
+        'be used to calculate grid weights. If None, they are tried to be '
+        'used.'],
+
     # decoder
     'decoder.x': [set(), validate_stringset,
                   'names that shall be interpreted as the longitudinal x dim'],
@@ -1183,3 +1182,5 @@ _str_err_msg = ('You must supply exactly {n:d} comma-separated values, '
 #: formatoptions and configuration settings.
 rcParams = RcParams()
 rcParams.update_from_defaultParams()
+
+defaultParams_orig = defaultParams.copy()
