@@ -6,6 +6,7 @@ the core of the visualization in the :mod:`psyplot` package. Each
 key is represented by a :class:`Formatoption` subclass."""
 
 import six
+import weakref
 from abc import ABCMeta, abstractmethod
 from textwrap import TextWrapper
 import logging
@@ -159,9 +160,22 @@ class Formatoption(object):
     #: :class:`~psyplot.plotter.Plotter` class
     key = None
 
-    #: :class:`~psyplot.plotter.Plotter`. Plotter instance this formatoption
-    #: belongs to
-    plotter = None
+    _plotter = None
+
+    @property
+    def plotter(self):
+        """:class:`~psyplot.plotter.Plotter`. Plotter instance this
+        formatoption belongs to"""
+        if self._plotter is None:
+            return
+        return self._plotter()
+
+    @plotter.setter
+    def plotter(self, value):
+        if value is not None:
+            self._plotter = weakref.ref(value)
+        else:
+            self._plotter = value
 
     #: `list of str`. List of formatoptions that have to be updated before this
     #: one is updated. Those formatoptions are only updated if they exist in
@@ -629,7 +643,7 @@ class Formatoption(object):
         This method should return a QWidget that is loaded by the psyplot-gui
         when the formatoption is selected in the
         :attr:`psyplot_gui.main.Mainwindow.fmt_widget`. It should call the
-        :method:`~psyplot_gui.fmt_widget.FormatoptionWidget.insert_text` method
+        :meth:`~psyplot_gui.fmt_widget.FormatoptionWidget.insert_text` method
         when the update text for the formatoption should be changed.
 
         Parameters
@@ -954,7 +968,21 @@ class Plotter(dict):
         self._ax = value
 
     #: The :class:`psyplot.project.Project` instance this plotter belongs to
-    project = None
+    _project = None
+
+    @property
+    def project(self):
+        """:class:`psyplot.project.Project` instance this plotter belongs to"""
+        if self._project is None:
+            return
+        return self._project()
+
+    @project.setter
+    def project(self, value):
+        if value is not None:
+            self._project = weakref.ref(value)
+        else:
+            self._project = value
 
     @property
     @dedent
@@ -1094,7 +1122,7 @@ class Plotter(dict):
     @docstrings.get_sectionsf('Plotter')
     @docstrings.dedent
     def __init__(self, data=None, ax=None, auto_update=None, project=None,
-                 draw=None, make_plot=True, clear=False,
+                 draw=False, make_plot=True, clear=False,
                  enable_post=False, **kwargs):
         """
         Parameters
@@ -1268,7 +1296,7 @@ class Plotter(dict):
 
     @docstrings.dedent
     def initialize_plot(self, data=None, ax=None, make_plot=True, clear=False,
-                        draw=None, remove=False):
+                        draw=False, remove=False, priority=None):
         """
         Initialize the plot for a data array
 
@@ -1285,7 +1313,12 @@ class Plotter(dict):
         %(InteractiveBase.start_update.parameters.draw)s
         remove: bool
             If True, old effects by the formatoptions in this plotter are
-            undone first"""
+            undone first
+        priority: int
+            If given, initialize only the formatoption with the given priority.
+            This value must be out of :data:`START`, :data:`BEFOREPLOTTING` or
+            :data:`END`
+        """
         if data is None and self.data is not None:
             data = self.data
         else:
@@ -1304,7 +1337,7 @@ class Plotter(dict):
             for fmto in self._fmtos:
                 try:
                     fmto.remove()
-                except:
+                except Exception:
                     self.logger.debug(
                         "Could not remove %s while initializing", fmto.key,
                         exc_info=True)
@@ -1318,8 +1351,10 @@ class Plotter(dict):
             sorted(self._fmtos, key=lambda fmto: fmto.key)))
         self.plot_data = self.data
         self._updating = True
-        for priority, grouper in fmto_groups:
-            self._plot_by_priority(priority, grouper, initializing=True)
+        for fmto_priority, grouper in fmto_groups:
+            if priority is None or fmto_priority == priority:
+                self._plot_by_priority(fmto_priority, grouper,
+                                       initializing=True)
         self._release_all(True)  # finish the update
         self.cleared = False
         self.replot = False
@@ -2335,8 +2370,8 @@ class Plotter(dict):
             if len(base_variables) > 1:  # multiple variables
                 for name, base_var in six.iteritems(base_variables):
                     attrs.update(
-                        {name+key: value for key, value in six.iteritems(
-                            base_var.attrs)})
+                        {six.text_type(name)+key: value
+                         for key, value in six.iteritems(base_var.attrs)})
             else:
                 base_var = next(six.itervalues(base_variables))
             attrs['name'] = arr.name
