@@ -208,6 +208,16 @@ class Project(ArrayList):
         return (getattr(p0, key) for key in set(p0).intersection(
             *map(set, plotters[1:])))
 
+    @property
+    def is_csp(self):
+        """Boolean that is True if the project is the current subproject"""
+        return self is _current_subproject
+
+    @property
+    def is_cmp(self):
+        """Boolean that is True if the project is the current main project"""
+        return self is _current_project
+
     @property
     def figs(self):
         """A mapping from figures to data objects with the plotter in this
@@ -382,7 +392,11 @@ class Project(ArrayList):
     def extend(self, *args, **kwargs):
         len0 = len(self)
         ret = super(Project, self).extend(*args, **kwargs)
-        if len(self) > len0 and (self is gcp() or self is gcp(True)):
+        if self._main is None:
+            for arr in self:
+                if arr.psy.plotter is not None:
+                    arr.psy.plotter._project = self
+        if len(self) > len0 and (self.is_csp or self.is_cmp):
             self.oncpchange.emit(self)
         return ret
 
@@ -392,7 +406,11 @@ class Project(ArrayList):
     def append(self, *args, **kwargs):
         len0 = len(self)
         ret = super(Project, self).append(*args, **kwargs)
-        if len(self) > len0 and (self is gcp() or self is gcp(True)):
+        if self._main is None:
+            for arr in self:
+                if arr.psy.plotter is not None:
+                    arr.psy.plotter._project = self
+        if len(self) > len0 and (self.is_csp or self.is_cmp):
             self.oncpchange.emit(self)
         return ret
 
@@ -433,7 +451,10 @@ class Project(ArrayList):
             if data:
                 self.remove(arr)
                 if not self.is_main:
-                    self.main.remove(arr)
+                    try:
+                        self.main.remove(arr)
+                    except ValueError:  # arr not in list
+                        pass
             if close_ds:
                 if isinstance(arr, InteractiveList):
                     for ds in [val['ds'] for val in six.itervalues(
@@ -445,9 +466,9 @@ class Project(ArrayList):
                     arr.psy.base.close()
         if self.is_main and self is gcp(True) and data:
             scp(None)
-        elif self.is_main and self is gcp(True):
+        elif self.is_main and self.is_cmp:
             self.oncpchange.emit(self)
-        elif self.main is gcp(True):
+        elif self.main.is_cmp:
             self.oncpchange.emit(self.main)
 
     docstrings.keep_params('multiple_subplots.parameters', 'delete')
@@ -462,9 +483,9 @@ class Project(ArrayList):
                                         'Returns'])
     @docstrings.dedent
     def _add_data(self, plotter_cls, filename_or_obj, fmt={}, make_plot=True,
-                  draw=None, mf_mode=False, ax=None, engine=None, delete=True,
+                  draw=False, mf_mode=False, ax=None, engine=None, delete=True,
                   share=False, clear=False, enable_post=None,
-                  concat_dim=_concat_dim_default,
+                  concat_dim=_concat_dim_default, load=False,
                   *args, **kwargs):
         """
         Extract data from a dataset and visualize it with the given plotter
@@ -516,6 +537,10 @@ class Project(ArrayList):
             formatoption in `fmt` or `kwargs`
         %(xarray.open_mfdataset.parameters.concat_dim)s
             This parameter only does have an effect if `mf_mode` is True.
+        load: bool
+            If True, load the complete dataset into memory before plotting.
+            This might be useful if the data of other variables in the dataset
+            has to be accessed multiple times, e.g. for unstructured grids.
         %(ArrayList.from_dataset.parameters.no_base)s
 
         Other Parameters
@@ -537,6 +562,11 @@ class Project(ArrayList):
             else:
                 filename_or_obj = open_dataset(filename_or_obj,
                                                engine=engine)
+        if load:
+            old = filename_or_obj
+            filename_or_obj = filename_or_obj.load()
+            old.close()
+
         fmt = dict(fmt)
         possible_fmts = list(plotter_cls._get_formatoptions())
         additional_fmt, kwargs = utils.sort_kwargs(
@@ -1103,7 +1133,7 @@ class Project(ArrayList):
     @docstrings.get_sectionsf('Project.load_project')
     @docstrings.dedent
     def load_project(cls, fname, auto_update=None, make_plot=True,
-                     draw=None, alternative_axes=None, main=False,
+                     draw=False, alternative_axes=None, main=False,
                      encoding=None, enable_post=False, new_fig=True,
                      clear=None, **kwargs):
         """
@@ -1210,8 +1240,6 @@ class Project(ArrayList):
             # we create a new project with the project factory to make sure
             # that everything is handled correctly
             obj = project(None, obj)
-        else:
-            obj._main = gcp(True)
         axes = {}
         arr_names = obj.arr_names
         sharex = defaultdict(set)
@@ -1257,11 +1285,15 @@ class Project(ArrayList):
             if ax_base is not None:
                 ax_base.get_shared_x_axes().join(
                     ax_base, *obj(arr_name=names).axes)
+                for ax in obj(arr_name=names).axes:
+                    ax._sharex = ax_base
         for key, names in sharey.items():
             ax_base = get_ax_base(key, names)
             if ax_base is not None:
                 ax_base.get_shared_y_axes().join(
                     ax_base, *obj(arr_name=names).axes)
+                for ax in obj(arr_name=names).axes:
+                    ax._sharey = ax_base
         for arr in obj.with_plotter:
             shared = d['arrays'][arr.psy.arr_name]['plotter'].get('shared', {})
             for key, arr_names in six.iteritems(shared):
@@ -1282,9 +1314,10 @@ class Project(ArrayList):
                     obj.show()
         if auto_update is None:
             auto_update = rcParams['lists.auto_update']
-        obj.no_auto_update = not auto_update
-        if not obj.is_main:
+        if not main:
+            obj._main = gcp(True)
             obj.main.extend(obj, new_name=True)
+        obj.no_auto_update = not auto_update
         scp(obj)
         return obj
 
@@ -1371,7 +1404,7 @@ class _ProjectLoader(object):
         return fig.number, {
             'num': fig.number,
             'figsize': (fig.get_figwidth(), fig.get_figheight()),
-            'dpi': fig.get_dpi(),
+            'dpi': fig.get_dpi() / getattr(fig.canvas, '_dpi_ratio', 1),
             'facecolor': fig.get_facecolor(),
             'edgecolor': fig.get_edgecolor(),
             'frameon': fig.get_frameon(),
